#!/bin/sh
#

source ${PRODUCTS}/setup
flvr=`ups flavor`
heppdtdir=${PRODUCTS}/heppdt/v3_04_01/${flvr}
heppdtsrc=${PRODUCTS}/heppdt/v3_04_01/source/HepPDT-3.04.01

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

mkdir -p ${heppdtdir}/build
if [ ! -d ${heppdtdir}/build ]
then
   echo "ERROR: failed to create ${heppdtdir}/build"
   exit 1
fi
cd ${heppdtdir}/build

set -x

${heppdtsrc}/configure --prefix=${heppdtdir} 
make 
make check
make install 

set +x

if [ ! -d ${heppdtdir}/lib ]
then
   echo "ERROR: failed to create ${heppdtdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
if [ "${flvr}" = "Linux64bit+2.6-2.5" ] || [ "${flvr}" = "Linux+2.6-2.5" ] || \
   [ "${flvr}" = "Linux64bit+2.6-2.3.4"  ] || [ "${flvr}" = "Linux+2.6-2.3.4" ]
then
   echo "Finished building heppdt for flavor ${flvr}"
else 
   echo "Finished building heppdt for unsupported flavor ${flvr}"
   echo "Declaring heppdt v3_04_01 for this flavor"
   ups declare heppdt v3_04_01 -r heppdt/v3_04_01 -4 -m heppdt.table
fi
setup heppdt v3_04_01
echo "heppdt libraries are installed at ${HEPPDT_LIB}"

exit 0
